summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2000-08-30 13:51:24 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2000-08-30 13:51:24 +0000
commit45c9e83b07a146ad42e19f44b9def27ecbdcd9e2 (patch)
treea2baac2860572164bf5c375a2fe8d90a40080611
parentbc1ad33168dad61eed9029d25ff2214e8d8845ce (diff)
downloadperl-45c9e83b07a146ad42e19f44b9def27ecbdcd9e2.tar.gz
Reset archname and archname64 always, forcing them be
recomputed at each Configure run, make Configure and the hints files agree on the naming of largefiles variables. p4raw-id: //depot/perl@6912
-rwxr-xr-xConfigure4
-rwxr-xr-xconfigpm4
-rw-r--r--hints/aix.sh20
-rw-r--r--hints/hpux.sh4
-rw-r--r--hints/linux.sh4
-rw-r--r--hints/solaris_2.sh12
6 files changed, 25 insertions, 23 deletions
diff --git a/Configure b/Configure
index d4b6dba856..4f8f3cb35b 100755
--- a/Configure
+++ b/Configure
@@ -20,7 +20,7 @@
# $Id: Head.U,v 3.0.1.9 1997/02/28 15:02:09 ram Exp $
#
-# Generated on Wed Aug 30 03:53:15 EET DST 2000 [metaconfig 3.0 PL70]
+# Generated on Wed Aug 30 16:44:38 EET DST 2000 [metaconfig 3.0 PL70]
# (with additional metaconfig patches by perlbug@perl.org)
cat >/tmp/c1$$ <<EOF
@@ -975,6 +975,7 @@ useopcode=true
_exe=''
: Extra object files, if any, needed on this platform.
archobjs=''
+archname=''
: Possible local include directories to search.
: Set locincpth to "" in a hint file to defeat local include searches.
locincpth="/usr/local/include /opt/local/include /usr/gnu/include"
@@ -1006,6 +1007,7 @@ plibpth=''
libswanted=''
: some systems want to use only the non-versioned libso:s
ignore_versioned_solibs=''
+archname64=''
ccflags_uselargefiles=''
ldflags_uselargefiles=''
libswanted_uselargefiles=''
diff --git a/configpm b/configpm
index 9defbe4df1..31b416b7a3 100755
--- a/configpm
+++ b/configpm
@@ -148,13 +148,13 @@ sub FETCH {
} elsif ($_[1] =~ /^((?:cc|ld)flags|libs(?:wanted)?)_nolargefiles/) {
# These are purely virtual, they do not exist, but need to
# be computed on demand for largefile-incapable extensions.
- my $key = "${1}_largefiles";
+ my $key = "${1}_uselargefiles";
$value = $Config{$1};
my $withlargefiles = $Config{$key};
if ($key =~ /^(?:cc|ld)flags_/) {
$value =~ s/\Q$withlargefiles\E\b//;
} elsif ($key =~ /^libs/) {
- my @lflibswanted = split(' ', $Config{libswanted_largefiles});
+ my @lflibswanted = split(' ', $Config{libswanted_uselargefiles});
if (@lflibswanted) {
my %lflibswanted;
@lflibswanted{@lflibswanted} = ();
diff --git a/hints/hpux.sh b/hints/hpux.sh
index ecfcb6d572..522fd46fa1 100644
--- a/hints/hpux.sh
+++ b/hints/hpux.sh
@@ -388,9 +388,9 @@ case "$uselargefiles" in
''|$define|true|[yY]*)
# there are largefile flags available via getconf(1)
# but we cheat for now. (Keep that in the left margin.)
-ccflags_largefiles="-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
+ccflags_uselargefiles="-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
- ccflags="$ccflags $ccflags_largefiles"
+ ccflags="$ccflags $ccflags_uselargefiles"
if test -z "$ccisgcc" -a -z "$gccversion"; then
# The strict ANSI mode (-Aa) doesn't like large files.
diff --git a/hints/linux.sh b/hints/linux.sh
index 0fa46bd05d..913cfd0fd1 100644
--- a/hints/linux.sh
+++ b/hints/linux.sh
@@ -283,9 +283,9 @@ cat > UU/uselargefiles.cbu <<'EOCBU'
case "$uselargefiles" in
''|$define|true|[yY]*)
# Keep this in the left margin.
-ccflags_largefiles="-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
+ccflags_uselargefiles="-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64"
- ccflags="$ccflags $ccflags_largefiles"
+ ccflags="$ccflags $ccflags_uselargefiles"
;;
esac
EOCBU
diff --git a/hints/solaris_2.sh b/hints/solaris_2.sh
index f698a502ff..bf2f1956a0 100644
--- a/hints/solaris_2.sh
+++ b/hints/solaris_2.sh
@@ -379,13 +379,13 @@ case "$uselargefiles" in
''|$define|true|[yY]*)
# Keep these in the left margin.
-ccflags_largefiles="`getconf LFS_CFLAGS 2>/dev/null`"
-ldflags_largefiles="`getconf LFS_LDFLAGS 2>/dev/null`"
-libswanted_largefiles="`getconf LFS_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
+ccflags_uselargefiles="`getconf LFS_CFLAGS 2>/dev/null`"
+ldflags_uselargefiles="`getconf LFS_LDFLAGS 2>/dev/null`"
+libswanted_uselargefiles="`getconf LFS_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
- ccflags="$ccflags $ccflags_largefiles"
- ldflags="$ldflags $ldflags_largefiles"
- libswanted="$libswanted $libswanted_largefiles"
+ ccflags="$ccflags $ccflags_uselargefiles"
+ ldflags="$ldflags $ldflags_uselargefiles"
+ libswanted="$libswanted $libswanted_uselargefiles"
;;
esac
EOCBU
diff --git a/hints/aix.sh b/hints/aix.sh
index c6a8c52e24..c07e79cc68 100644
--- a/hints/aix.sh
+++ b/hints/aix.sh
@@ -207,26 +207,26 @@ cat > UU/uselargefiles.cbu <<'EOCBU'
case "$uselargefiles" in
''|$define|true|[yY]*)
# Keep these at the left margin.
-ccflags_largefiles="`getconf XBS5_ILP32_OFFBIG_CFLAGS 2>/dev/null`"
-ldflags_largefiles="`getconf XBS5_ILP32_OFFBIG_LDFLAGS 2>/dev/null`"
+ccflags_uselargefiles="`getconf XBS5_ILP32_OFFBIG_CFLAGS 2>/dev/null`"
+ldflags_uselargefiles="`getconf XBS5_ILP32_OFFBIG_LDFLAGS 2>/dev/null`"
# _Somehow_ in AIX 4.3.1.0 the above getconf call manages to
# insert(?) *something* to $ldflags so that later (in Configure) evaluating
# $ldflags causes a newline after the '-b64' (the result of the getconf).
# (nothing strange shows up in $ldflags even in hexdump;
# so it may be something (a bug) in the shell, instead?)
# Try it out: just uncomment the below line and rerun Configure:
-# echo >&4 "AIX 4.3.1.0 $ldflags_largefiles mystery" ; exit 1
+# echo >&4 "AIX 4.3.1.0 $ldflags_uselargefiles mystery" ; exit 1
# Just don't ask me how AIX does it, I spent hours wondering.
# Therefore the line re-evaluating ldflags_largefiles: it seems to fix
# the whatever it was that AIX managed to break. --jhi
- ldflags_largefiles="`echo $ldflags_largefiles`"
+ ldflags_uselargefiles="`echo $ldflags_uselargefiles`"
# Keep this at the left margin.
-libswanted_largefiles="`getconf XBS5_ILP32_OFFBIG_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
- case "$ccflags_largefiles$ldflags_largefiles$libs_largefiles" in
+libswanted_uselargefiles="`getconf XBS5_ILP32_OFFBIG_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
+ case "$ccflags_uselargefiles$ldflags_uselargefiles$libs_uselargefiles" in
'');;
- *) ccflags="$ccflags $ccflags_largefiles"
- ldflags="$ldflags $ldflags_largefiles"
- libswanted="$libswanted $libswanted_largefiles"
+ *) ccflags="$ccflags $ccflags_uselargefiles"
+ ldflags="$ldflags $ldflags_uselargefiles"
+ libswanted="$libswanted $libswanted_uselargefiles"
;;
esac
case "$gccversion" in
@@ -207,26 +207,26 @@ cat > UU/uselargefiles.cbu <<'EOCBU'
# Just don't ask me how AIX does it, I spent hours wondering.
- # Therefore the line re-evaluating ldflags_largefiles: it seems to fix
+ # Therefore the line re-evaluating ldflags_uselargefiles: it seems to fix
# the whatever it was that AIX managed to break. --jhi